summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/mon-project.cc
diff options
context:
space:
mode:
authorNeil Moore <neil@s-z.org>2013-08-29 08:12:02 -0400
committerNeil Moore <neil@s-z.org>2013-08-29 08:12:02 -0400
commitb53826c5c3549fb1b1b35d10e0f939b5ac67e9fe (patch)
tree9d3343d3916d025b9a74237d6aef4719bee99e6f /crawl-ref/source/mon-project.cc
parent843eb5efb98bf5b815aed5dc4ad3df99cd53a8ce (diff)
downloadcrawl-ref-b53826c5c3549fb1b1b35d10e0f939b5ac67e9fe.tar.gz
crawl-ref-b53826c5c3549fb1b1b35d10e0f939b5ac67e9fe.zip
Don't let IOOD circle submerged creatures (#7520).
Diffstat (limited to 'crawl-ref/source/mon-project.cc')
-rw-r--r--crawl-ref/source/mon-project.cc5
1 files changed, 3 insertions, 2 deletions
diff --git a/crawl-ref/source/mon-project.cc b/crawl-ref/source/mon-project.cc
index fda3339322..a609cfa688 100644
--- a/crawl-ref/source/mon-project.cc
+++ b/crawl-ref/source/mon-project.cc
@@ -299,8 +299,9 @@ bool iood_act(monster& mon, bool no_trail)
// If the target is gone, the orb continues on a ballistic course since
// picking a new one would require intelligence.
- // Boulders don't home onto their targets.
- if (iood && foe)
+ // Boulders don't home onto their targets. IOODs can't home in on a
+ // submerged creature.
+ if (iood && foe && !foe->submerged())
{
const coord_def target = foe->pos();
float dx = target.x - x;